@@ -21,7 +21,7 @@ from fmdt.args import (
 )
 
 from fmdt.utils import (
-    condense_start_end,
+    condense_start_end
 )
 
 from fmdt.truth import (
@@ -49,7 +49,13 @@ from fmdt.config import (
     listdir_window,
     setdir_draco6,
     setdir_draco12,
-    setdir_window
+    setdir_window,
+    init_cache,
+    clear_cache,
+    cache_dir,
+    cache_info,
+    listdir_cache,
+    size_cache
 )
 
 from fmdt.db import (
@@ -59,13 +65,18 @@ from fmdt.db import (
     load_draco6,
     load_draco12,
     load_window,
-    info as db_info
+    load_demo,
+    info as local_info
 )
 
+init_cache()
+
+
+
 # from fmdt.truth import HumanDetection
 
 MAJOR_VERSION = 0
 MINOR_VERSION = 0
-PATCH         = 29
+PATCH         = 31 
 
 VERSION = str(MAJOR_VERSION) + "." + str(MINOR_VERSION) + "." + str(PATCH)
