@@ -30,4 +30,25 @@ print(".")
 print(f"{vids[-1].id()}: {vids[-1]} has {len(vids[-1].meteors())} meteor(s) in our database")
 
 id = 17
-print(f"vids[{id}].meteors() -> {vids[id].meteors()[0]}")
\ No newline at end of file
+v = vids[id]
+print(f"vids[{id}].meteors() -> {v.meteors()[0]} and has full dir: {v.full_path()}")
+
+on_disc = [v for v in vids if v.exists()]
+has_meteors = [v for v in on_disc if v.has_meteors()]
+
+print(f"{len(on_disc)} videos exist on disc out of {len(vids)}")
+print(f"{len(has_meteors)} videos have meteors and exist on disk")
+
+# Let's get some diagnostics then.
+
+# Like: How many videos exist from our database exist on disk?
+
+d6 = fmdt.load_draco6()
+d12 = fmdt.load_draco12()
+w = fmdt.load_window()
+
+
+fmdt.db.info()
+
+print(w)
+print(w[0].full_path())
\ No newline at end of file
